@@ -171,18 +171,20 @@ open_file_ok_cb (GtkWidget *w,
 							      window->compression);
 
 			} else 
-				fr_archive_add (window->archive,
-						files,
-						base_dir,
-						update,
-						window->password,
-						window->compression);
+				window_archive_add (window,
+						    files,
+						    base_dir,
+						    window_get_current_location (window),
+						    update,
+						    window->password,
+						    window->compression);
 
 			g_free (first_path);
 		}
 		
 		g_list_free (files);
 		g_strfreev (selections); 
+
 	} else {
 		gboolean    recursive;
 		gboolean    no_symlinks;
@@ -348,7 +350,7 @@ add_cb (GtkWidget *widget,
  
 	data = g_new (DialogData, 1);
 	data->window = callback_data;
-	data->dialog = file_sel = gtk_file_selection_new (_("Add Files"));
+	data->dialog = file_sel = gtk_file_selection_new (_("Add"));
 	gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (file_sel));
 
 	gtk_file_selection_set_select_multiple (GTK_FILE_SELECTION (file_sel), TRUE);
