@@ -43,13 +43,13 @@ enum {
 	FILE_MENU_OPEN_ARCHIVE,
 	FILE_MENU_RECENTS_MENU,
 	FILE_MENU_SEP1,
-	FILE_MENU_OPEN,
-	FILE_MENU_VIEW,
+	FILE_MENU_SAVE_AS_ARCHIVE,
 	FILE_MENU_SEP2,
 	FILE_MENU_RANAME_ARCHIVE,
 	FILE_MENU_COPY_ARCHIVE,
 	FILE_MENU_MOVE_ARCHIVE,
 	FILE_MENU_DELETE_ARCHIVE,
+	FILE_MENU_TEST,
 	FILE_MENU_SEP3,
 	FILE_MENU_ARCHIVE_PROP,
 	FILE_MENU_SEP4,
@@ -63,142 +63,119 @@ GnomeUIInfo recents_menu[] = {
 };
 
 GnomeUIInfo file_menu[] = {
-	{ GNOME_APP_UI_ITEM, 
-	  N_("_New"), N_("Create a new archive"), 
-	  new_archive_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_NEW,
-	  'n', GDK_CONTROL_MASK, NULL },
+	GNOMEUIINFO_MENU_NEW_ITEM (N_("_New"), 
+				   N_("Create a new archive"), 
+				   new_archive_cb, NULL),
 
-	{ GNOME_APP_UI_ITEM, 
-	  N_("_Open..."), N_("Open an existing archive"), 
-	  open_archive_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_OPEN,
-	  'o', GDK_CONTROL_MASK, NULL },
+	GNOMEUIINFO_MENU_OPEN_ITEM (open_archive_cb, NULL),
 
 	GNOMEUIINFO_SUBTREE (N_("Open R_ecent"), recents_menu),
 
 	GNOMEUIINFO_SEPARATOR,
 
-	{ GNOME_APP_UI_ITEM, 
-	  N_("Open Fi_les..."), N_("Open selected files with an application"), 
-	  open_with_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, 0,
-	  0, 0, NULL },
-
-	{ GNOME_APP_UI_ITEM, 
-	  N_("_View File"), N_("View file with internal viewer"), 
-	  view_or_open_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, 0,
-	  'v', GDK_CONTROL_MASK, NULL },
+	GNOMEUIINFO_MENU_SAVE_AS_ITEM (save_as_archive_cb, NULL),
 
 	GNOMEUIINFO_SEPARATOR,
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("_Rename"), N_("Rename current archive"), 
+	  N_("_Rename..."), N_("Rename current archive"), 
 	  rename_archive_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("Cop_y"), N_("Copy current archive to another folder"), 
+	  N_("Cop_y..."), N_("Copy current archive to another folder"), 
 	  copy_archive_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("_Move"), N_("Move current archive to another folder"), 
+	  N_("_Move..."), N_("Move current archive to another folder"), 
 	  move_archive_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("_Delete"), N_("Delete current archive from disk"), 
+	  N_("Move to _Trash"), N_("Move current archive to trash"), 
 	  delete_archive_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_DELETE,
 	  0, 0, NULL },
 
+	{ GNOME_APP_UI_ITEM, 
+	  N_("_Test"), N_("Test whether the archive contains errors"),
+	  test_cb, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, 0,
+	  0, 0, NULL },
+
 	GNOMEUIINFO_SEPARATOR,
 
 	{ GNOME_APP_UI_ITEM,
 	  N_("_Properties"), N_("Show archive properties"),
 	  dlg_prop, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PROPERTIES,
-	  'i', GDK_CONTROL_MASK, NULL },
+	  0, 0, NULL },
 
 	GNOMEUIINFO_SEPARATOR,
 
-	{ GNOME_APP_UI_ITEM, 
-	  N_("_Close"), N_("Close current archive"), 
-	  close_archive_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CLOSE,
-	  0, 0, NULL },
+	GNOMEUIINFO_MENU_CLOSE_ITEM (close_archive_cb, NULL),
 
-	{ GNOME_APP_UI_ITEM, 
-	  N_("E_xit"), N_("Exit"), 
-	  quit_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_QUIT, 
-	  'q', GDK_CONTROL_MASK, NULL },
+	GNOMEUIINFO_MENU_QUIT_ITEM(quit_cb, NULL),
 
 	GNOMEUIINFO_END
 };
 
 enum {
 	EDIT_MENU_ADD = 0,
-	EDIT_MENU_DELETE,
 	EDIT_MENU_EXTRACT,
-	/*EDIT_MENU_UUENCODE,*/
-	EDIT_MENU_TEST,
-	/*EDIT_MENU_COMMENT,*/
 	EDIT_MENU_SEP1,
+	EDIT_MENU_CUT,
+	EDIT_MENU_COPY,
+	EDIT_MENU_PASTE,
+	EDIT_MENU_RENAME,
+	EDIT_MENU_DELETE,
+	EDIT_MENU_SEP2,
 	EDIT_MENU_SELECT_ALL,
 	EDIT_MENU_DESELECT_ALL,
-	EDIT_MENU_SEP2,
-	EDIT_MENU_PASSWORD,
 	EDIT_MENU_SEP3,
+	EDIT_MENU_OPEN,
+	EDIT_MENU_VIEW,
+	EDIT_MENU_SEP4,
+	EDIT_MENU_PASSWORD,
+	EDIT_MENU_SEP5,
 	EDIT_MENU_PREFERENCES,
 	EDIT_MENU_LENGTH
 };
 
 GnomeUIInfo edit_menu[] = {
 	{ GNOME_APP_UI_ITEM, 
-	  N_("Add _Files..."), N_("Add files to the archive"), 
+	  N_("_Add..."), N_("Add files and folders to the archive"), 
 	  add_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ADD,
-	  'z', GDK_CONTROL_MASK, NULL },
+	  0, 0, NULL },
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("_Delete"), N_("Delete selected files and folders from the archive"), 
-	  dlg_delete, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REMOVE,
-	  'd', GDK_CONTROL_MASK, NULL },
-
-	{ GNOME_APP_UI_ITEM, 
-	  N_("_Extract to..."), N_("Extract files from the archive"), 
+	  N_("_Extract..."), N_("Extract files from the archive"), 
 	  dlg_extract, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
-	  'x', GDK_CONTROL_MASK, NULL },
-
-	/* FIXME
-	{ GNOME_APP_UI_ITEM, 
-	  N_("_UUencode..."), " ",
-	  NULL, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, 0,
-	  0, 0, NULL },
-	*/
-
-	{ GNOME_APP_UI_ITEM, 
-	  N_("_Test Archive"), " ",
-	  test_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
 
-	/* FIXME
+	GNOMEUIINFO_SEPARATOR,
+
+	GNOMEUIINFO_MENU_CUT_ITEM (cut_cb, NULL),
+	GNOMEUIINFO_MENU_COPY_ITEM (copy_cb, NULL),
+	GNOMEUIINFO_MENU_PASTE_ITEM (paste_cb, NULL),
+
 	{ GNOME_APP_UI_ITEM, 
-	  N_("C_omment..."), " ",
-	  NULL, NULL, NULL,
+	  N_("_Rename..."), N_("Rename selection"), 
+	  rename_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
+	  GDK_F2, 0, NULL },
+
+	{ GNOME_APP_UI_ITEM, 
+	  N_("_Delete..."), N_("Delete selection from the archive"), 
+	  dlg_delete, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REMOVE,
 	  0, 0, NULL },
-	*/
 
 	GNOMEUIINFO_SEPARATOR,
 
@@ -212,7 +189,21 @@ GnomeUIInfo edit_menu[] = {
 	  N_("Dese_lect All"), N_("Deselect all files"), 
 	  deselect_all_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
-	  'a', GDK_SHIFT_MASK | GDK_CONTROL_MASK, NULL },
+	  0, 0, NULL },
+
+	GNOMEUIINFO_SEPARATOR,
+
+	{ GNOME_APP_UI_ITEM, 
+	  N_("Open Fi_les..."), N_("Open selected files with an application"), 
+	  open_with_cb, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, 0,
+	  0, 0, NULL },
+
+	{ GNOME_APP_UI_ITEM, 
+	  N_("_View File"), N_("View file with internal viewer"), 
+	  view_or_open_cb, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, 0,
+	  0, 0, NULL },
 
 	GNOMEUIINFO_SEPARATOR,
 
@@ -225,10 +216,10 @@ GnomeUIInfo edit_menu[] = {
 	GNOMEUIINFO_SEPARATOR,
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("_Preferences"), " ", 
+	  N_("_Preferences"), N_("Edit File Roller preferences"), 
 	  dlg_preferences, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PREFERENCES, 
-	  'p', GDK_CONTROL_MASK, NULL },
+	  0, 0, NULL },
 
 	GNOMEUIINFO_END
 };
@@ -254,13 +245,13 @@ GnomeUIInfo sort_by_radio_list[] = {
           0, 0, NULL },
         
         { GNOME_APP_UI_ITEM, 
-          N_("by _Time"), N_("Sort file list by modification time"), 
+          N_("by _Date modified"), N_("Sort file list by modification time"), 
 	  sort_list_by_time, NULL, NULL,
           GNOME_APP_PIXMAP_NONE, NULL,
           0, 0, NULL },
 
         { GNOME_APP_UI_ITEM, 
-          N_("by _Path"), N_("Sort file list by path"), 
+          N_("by _Location"), N_("Sort file list by location"), 
 	  sort_list_by_path, NULL, NULL,
           GNOME_APP_PIXMAP_NONE, NULL,
           0, 0, NULL },
@@ -314,16 +305,16 @@ GnomeUIInfo arrange_menu[] = {
 };
 
 enum {
-	VIEW_MENU_TOOLBAR,
+	VIEW_MENU_TOOLBAR = 0,
 	VIEW_MENU_STATUSBAR,
 	VIEW_MENU_SEP1,
 	VIEW_MENU_STOP,
 	VIEW_MENU_RELOAD,
-	VIEW_MENU_SEP2,
-	VIEW_MENU_VIEW_LIST,
 	VIEW_MENU_SEP3,
-	VIEW_MENU_SORT_LIST,
+	VIEW_MENU_VIEW_LIST,
 	VIEW_MENU_SEP4,
+	VIEW_MENU_SORT_LIST,
+	VIEW_MENU_SEP5,
 	VIEW_MENU_LAST_OUTPUT
 };
 
@@ -365,7 +356,7 @@ GnomeUIInfo view_menu[] = {
 	GNOMEUIINFO_SEPARATOR,
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("_Last Output"), " ", 
+	  N_("_Last Output"), N_("View the output produced by the last executed command"), 
 	  last_output_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
@@ -374,25 +365,6 @@ GnomeUIInfo view_menu[] = {
 };
 
 
-/* Definition of the Windows menu */
-
-GnomeUIInfo windows_menu[] = {
-	{ GNOME_APP_UI_ITEM, 
-	  N_("New _Window"), N_("Open a new window"), 
-	  new_window_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, 0,
-	  'w', GDK_SHIFT_MASK | GDK_CONTROL_MASK, NULL },
-
-	{ GNOME_APP_UI_ITEM, 
-	  N_("Clo_se Window"), N_("Close this window"), 
-	  close_window_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, 0,
-	  'w', GDK_CONTROL_MASK, NULL },
-	
-	GNOMEUIINFO_END
-};
-
-
 /* Definition of the Help menu */
 
 GnomeUIInfo help_menu[] = {
@@ -418,7 +390,6 @@ GnomeUIInfo main_menu[] = {
 	GNOMEUIINFO_SUBTREE (N_("_Archive"), file_menu),
 	GNOMEUIINFO_SUBTREE (N_("_Edit"), edit_menu),
 	GNOMEUIINFO_SUBTREE (N_("_View"), view_menu),
-	GNOMEUIINFO_SUBTREE (N_("_Windows"), windows_menu),
 	GNOMEUIINFO_MENU_HELP_TREE (help_menu),
 	GNOMEUIINFO_END
 };
@@ -428,26 +399,32 @@ GnomeUIInfo main_menu[] = {
 /* popup menus. */
 
 enum {
-	FILE_POPUP_MENU_OPEN,
+	FILE_POPUP_MENU_OPEN = 0,
 	FILE_POPUP_MENU_VIEW,
 	FILE_POPUP_MENU_SEP1,
 	FILE_POPUP_MENU_ADD,
-	FILE_POPUP_MENU_DELETE,
 	FILE_POPUP_MENU_EXTRACT,
 	FILE_POPUP_MENU_SEP2,
-	FILE_POPUP_MENU_SELECT_ALL
+	FILE_POPUP_MENU_CUT,
+	FILE_POPUP_MENU_COPY,
+	FILE_POPUP_MENU_PASTE,
+	FILE_POPUP_MENU_RENAME,
+	FILE_POPUP_MENU_DELETE,
+	FILE_POPUP_MENU_SEP3,
+	FILE_POPUP_MENU_SELECT_ALL,
+	FILE_POPUP_MENU_DESELECT_ALL
 };
 
 
 GnomeUIInfo file_popup_menu_data[] = {
 	{ GNOME_APP_UI_ITEM, 
-	  N_("Open Files..."), " ", 
+	  N_("Open Fi_les..."), N_("Open selected files with an application"),
 	  open_with_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("View File"), N_("View file with internal viewer"), 
+	  N_("_View File"), N_("View file with internal viewer"), 
 	  view_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
@@ -455,31 +432,49 @@ GnomeUIInfo file_popup_menu_data[] = {
 	GNOMEUIINFO_SEPARATOR,
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("Add Files..."), N_("Add files to the archive"), 
+	  N_("_Add..."), N_("Add files and folders to the archive"), 
 	  add_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ADD,
 	  0, 0, NULL },
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("Delete Files"), N_("Delete files from the archive"), 
-	  dlg_delete, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REMOVE,
-	  0, 0, NULL },
-
-	{ GNOME_APP_UI_ITEM, 
-	  N_("Extract to..."), N_("Extract files from the archive"), 
+	  N_("_Extract..."), N_("Extract files from the archive"), 
 	  dlg_extract, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
 
 	GNOMEUIINFO_SEPARATOR,
 
+	GNOMEUIINFO_MENU_CUT_ITEM (cut_cb, NULL),
+	GNOMEUIINFO_MENU_COPY_ITEM (copy_cb, NULL),
+	GNOMEUIINFO_MENU_PASTE_ITEM (paste_cb, NULL),
+
 	{ GNOME_APP_UI_ITEM, 
-	  N_("Select All"), " ", 
+	  N_("_Rename..."), N_("Rename selection"), 
+	  rename_cb, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, 0,
+	  0, 0, NULL },
+
+	{ GNOME_APP_UI_ITEM, 
+	  N_("_Delete..."), N_("Delete selection from the archive"),
+	  dlg_delete, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REMOVE,
+	  0, 0, NULL },
+
+	GNOMEUIINFO_SEPARATOR,
+
+	{ GNOME_APP_UI_ITEM, 
+	  N_("Select _All"), N_("Select all files"), 
 	  select_all_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
 
+	{ GNOME_APP_UI_ITEM, 
+	  N_("Dese_lect All"), N_("Deselect all files"), 
+	  deselect_all_cb, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, 0,
+	  0, 0, NULL },
+
 	GNOMEUIINFO_END
 };
 
